@@ -197,8 +197,8 @@ class SocketIO(object):
         self.manage_session = self.server_options.pop('manage_session',
                                                       self.manage_session)
 
-        if 'client_manager' not in self.server_options:
-            url = self.server_options.pop('message_queue', None)
+        if 'client_manager' not in kwargs:
+            url = self.server_options.get('message_queue', None)
             channel = self.server_options.pop('channel', 'flask-socketio')
             write_only = app is None
             if url:
@@ -434,7 +434,7 @@ class SocketIO(object):
                          only be used when addressing an individual client.
         """
         namespace = kwargs.pop('namespace', '/')
-        to = kwargs.pop('to', kwargs.pop('room', None))
+        to = kwargs.pop('to', None) or kwargs.pop('room', None)
         include_self = kwargs.pop('include_self', True)
         skip_sid = kwargs.pop('skip_sid', None)
         if not include_self and not skip_sid:
@@ -827,7 +827,7 @@ def emit(event, *args, **kwargs):
         namespace = flask.request.namespace
     callback = kwargs.get('callback')
     broadcast = kwargs.get('broadcast')
-    to = kwargs.pop('to', kwargs.pop('room', None))
+    to = kwargs.pop('to', None) or kwargs.pop('room', None)
     if to is None and not broadcast:
         to = flask.request.sid
     include_self = kwargs.get('include_self', True)
@@ -885,7 +885,7 @@ def send(message, **kwargs):
         namespace = flask.request.namespace
     callback = kwargs.get('callback')
     broadcast = kwargs.get('broadcast')
-    to = kwargs.pop('to', kwargs.pop('room', None))
+    to = kwargs.pop('to', None) or kwargs.pop('room', None)
     if to is None and not broadcast:
         to = flask.request.sid
     include_self = kwargs.get('include_self', True)
